local Hermes = _G['Hermes']

local LAM2 = LibAddonMenu2

local endeavorAlertLocation = { }
local endeavorAlertLocationLookup = { }
for i = 0, 1 do
    table.insert(endeavorAlertLocation, i)
    table.insert(endeavorAlertLocationLookup, Hermes.GetDefaultLocaleString("end_choice" .. i))
end

function Hermes:InitializeMenu()
    local panelData = {
        type = "panel",
        name = self.addonName,
        displayName = self.displayName,
        author = self.author,
        version = self.version,
        slashCommand = self.slashCommand,
        website = self.website,
        registerForRefresh = true,
        registerForDefaults = true,
    }

    local optionsTable = {
        {
            type = "header",
            name = GetString(SI_KEYBINDINGS_GENERIC_CATEGORY_NAME),
            width = "full",
        },
        {
            type = "checkbox",
            name = Hermes.GetDefaultLocaleString("show_teleport"),
            requiresReload = true,
            getFunc = function()
                return self.db.showTeleport
            end,
            setFunc = function(value)
                self.db.showTeleport = value
            end,
            default = self.db.showTeleport,
        },
        {
            type = "checkbox",
            name = Hermes.GetDefaultLocaleString("show_mail"),
            requiresReload = true,
            getFunc = function()
                return self.db.showMail
            end,
            setFunc = function(value)
                self.db.showMail = value
            end,
            default = self.db.showMail,
        },
        {
            type = "checkbox",
            name = Hermes.GetDefaultLocaleString("show_house"),
            requiresReload = true,
            getFunc = function()
                return self.db.showHouse
            end,
            setFunc = function(value)
                self.db.showHouse = value
            end,
            default = self.db.showHouse,
        },
        {
            type = "checkbox",
            name = Hermes.GetDefaultLocaleString("show_changelog"),
            getFunc = function()
                return self.db.showChangelog
            end,
            setFunc = function(value)
                self.db.showChangelog = value
            end,
            default = self.db.showChangelog,
        },
        {
            type = "submenu",
            name = Hermes.GetDefaultLocaleString("show_endeavors"),
            width = "full",
            controls = {
                {
                    type = "checkbox",
                    name = Hermes.GetDefaultLocaleString("end_progress"),
                    getFunc = function()
                        return self.db.enableEndeavorAlert
                    end,
                    setFunc = function(enable)
                        self.db.enableEndeavorAlert = enable
                    end,
                    default = self.db.enableEndeavorAlert,
                },
                {
                    type = "dropdown",
                    name = Hermes.GetDefaultLocaleString("end_location"),
                    choices = endeavorAlertLocationLookup,
                    choicesValues = endeavorAlertLocation,
                    getFunc = function()
                        return self.db.locationEndeavorAlert
                    end,
                    setFunc = function(value)
                        self.db.locationEndeavorAlert = value
                    end,
                    width = "full",
                    default = self.db.locationEndeavorAlert,
                    disabled = function()
                        return not self.db.enableEndeavorAlert
                    end
                },
                {
                    type = "colorpicker",
                    name = Hermes.GetDefaultLocaleString("end_color1"),
                    getFunc = function()
                        return self:ConvHexToRGB(self.db.endeavorColorDaily)
                    end,
                    setFunc = function(r, g, b)
                        self.db.endeavorColorDaily = self:ConvRGBToHex(r, g, b)
                    end,
                    disabled = function()
                        return not self.db.enableEndeavorAlert
                    end
                },
                {
                    type = "colorpicker",
                    name = Hermes.GetDefaultLocaleString("end_color2"),
                    getFunc = function()
                        return self:ConvHexToRGB(self.db.endeavorColorWeekly)
                    end,
                    setFunc = function(r, g, b)
                        self.db.endeavorColorWeekly = self:ConvRGBToHex(r, g, b)
                    end,
                    disabled = function()
                        return not self.db.enableEndeavorAlert
                    end
                },
                {
                    type = "checkbox",
                    name = Hermes.GetDefaultLocaleString("end_reward"),
                    getFunc = function()
                        return self.db.showEndeavorReward
                    end,
                    setFunc = function(enable)
                        self.db.showEndeavorReward = enable
                    end,
                    default = self.db.showEndeavorReward,
                    disabled = function()
                        return not self.db.enableEndeavorAlert
                    end
                },
            },
        },
        {
            type = "button",
            name = Hermes.GetDefaultLocaleString("button_changelog"),
            func = function()
                Hermes_Changelog:SetHidden(false)
            end,
            width = "half",
        },
    }
    self.panel = LAM2:RegisterAddonPanel(self.name .. "Options", panelData)
    LAM2:RegisterOptionControls(self.name .. "Options", optionsTable)
end
